==> huaweicloudsdkfunctiongraph-3.0.81-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/show_work_flow_metric_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowWorkFlowMetricRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'workflow_urn': 'str',
        'period': 'str'
    }

    attribute_map = {
        'workflow_urn': 'workflow_urn',
        'period': 'period'
    }

    def __init__(self, workflow_urn=None, period=None):
        """ShowWorkFlowMetricRequest - a model defined in huaweicloud sdk"""
        
        

        self._workflow_urn = None
        self._period = None
        self.discriminator = None

        self.workflow_urn = workflow_urn
        if period is not None:
            self.period = period

    @property
    def workflow_urn(self):
        """Gets the workflow_urn of this ShowWorkFlowMetricRequest.

        函数工作流URN, 格式为： urn:fss:<region_id>:<project_id>:workflow:\\<package\\>:<workflow_name>:\\<version\\> 注意： package当前只支持default version当前只支持latest

        :return: The workflow_urn of this ShowWorkFlowMetricRequest.
        :rtype: str
        """
        return self._workflow_urn

    @workflow_urn.setter
    def workflow_urn(self, workflow_urn):
        """Sets the workflow_urn of this ShowWorkFlowMetricRequest.

        函数工作流URN, 格式为： urn:fss:<region_id>:<project_id>:workflow:\\<package\\>:<workflow_name>:\\<version\\> 注意： package当前只支持default version当前只支持latest

        :param workflow_urn: The workflow_urn of this ShowWorkFlowMetricRequest.
        :type: str
        """
        self._workflow_urn = workflow_urn

    @property
    def period(self):
        """Gets the period of this ShowWorkFlowMetricRequest.

        时间段，单位为分钟

        :return: The period of this ShowWorkFlowMetricRequest.
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this ShowWorkFlowMetricRequest.

        时间段，单位为分钟

        :param period: The period of this ShowWorkFlowMetricRequest.
        :type: str
        """
        self._period = period

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowWorkFlowMetricRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkfunctiongraph-3.0.85-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/show_work_flow_metric_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowWorkFlowMetricRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'workflow_urn': 'str',
        'period': 'str'
    }

    attribute_map = {
        'workflow_urn': 'workflow_urn',
        'period': 'period'
    }

    def __init__(self, workflow_urn=None, period=None):
        """ShowWorkFlowMetricRequest

        The model defined in huaweicloud sdk

        :param workflow_urn: 函数工作流URN, 格式为： urn:fss:&lt;region_id&gt;:&lt;project_id&gt;:workflow:\\&lt;package\\&gt;:&lt;workflow_name&gt;:\\&lt;version\\&gt; 注意： package当前只支持default version当前只支持latest
        :type workflow_urn: str
        :param period: 时间段，单位为分钟
        :type period: str
        """
        
        

        self._workflow_urn = None
        self._period = None
        self.discriminator = None

        self.workflow_urn = workflow_urn
        if period is not None:
            self.period = period

    @property
    def workflow_urn(self):
        """Gets the workflow_urn of this ShowWorkFlowMetricRequest.

        函数工作流URN, 格式为： urn:fss:<region_id>:<project_id>:workflow:\\<package\\>:<workflow_name>:\\<version\\> 注意： package当前只支持default version当前只支持latest

        :return: The workflow_urn of this ShowWorkFlowMetricRequest.
        :rtype: str
        """
        return self._workflow_urn

    @workflow_urn.setter
    def workflow_urn(self, workflow_urn):
        """Sets the workflow_urn of this ShowWorkFlowMetricRequest.

        函数工作流URN, 格式为： urn:fss:<region_id>:<project_id>:workflow:\\<package\\>:<workflow_name>:\\<version\\> 注意： package当前只支持default version当前只支持latest

        :param workflow_urn: The workflow_urn of this ShowWorkFlowMetricRequest.
        :type workflow_urn: str
        """
        self._workflow_urn = workflow_urn

    @property
    def period(self):
        """Gets the period of this ShowWorkFlowMetricRequest.

        时间段，单位为分钟

        :return: The period of this ShowWorkFlowMetricRequest.
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this ShowWorkFlowMetricRequest.

        时间段，单位为分钟

        :param period: The period of this ShowWorkFlowMetricRequest.
        :type period: str
        """
        self._period = period

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowWorkFlowMetricRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
